Index: x264.c
===================================================================
--- x264.c	(revision 15077)
+++ x264.c	(working copy)
@@ -98,6 +98,11 @@
 #define NF_TEXT N_("Skip loop filter")
 #define NF_LONGTEXT N_( "Deactivate the deblocking loop filter (decreases quality).")
 
+#define FILTER_TEXT N_("Loop filter AlphaC0 and Beta parameters alpha:beta")
+#define FILTER_LONGTEXT N_( "Loop filter AlphaC0 and Beta parameters. " \
+    "Range -6 to 6 for both alpha and beta parameters. -6 means light " \
+    "filter, 6 means strong.")
+
 /* Ratecontrol */
 
 #define QP_TEXT N_("Set QP")
@@ -186,9 +191,22 @@
 
 #define SUBME_TEXT N_("Subpixel motion estimation and partition decision " \
     "quality")
+#if X264_BUILD >= 46 /* r477 */
+#define SUBME_MAX 7
 #define SUBME_LONGTEXT N_( "This parameter controls quality versus speed " \
     "tradeoffs involved in the motion estimation decision process " \
-    "(lower = quicker and higher = better quality). From 1 to 6." )
+    "(lower = quicker and higher = better quality). Range 1 to 7." )
+#elif X264_BUILD >= 30 /* r262 */
+#define SUBME_MAX 6
+#define SUBME_LONGTEXT N_( "This parameter controls quality versus speed " \
+    "tradeoffs involved in the motion estimation decision process " \
+    "(lower = quicker and higher = better quality). Range 1 to 6." )
+#else
+#define SUBME_MAX 5
+#define SUBME_LONGTEXT N_( "This parameter controls quality versus speed " \
+    "tradeoffs involved in the motion estimation decision process " \
+    "(lower = quicker and higher = better quality). Range 1 to 5." )
+#endif
 
 #define B_RDO_TEXT N_("RD based mode decision for B-frames.")
 #define B_RDO_LONGTEXT N_( "RD based mode decision for B-frames. This " \
@@ -232,6 +250,9 @@
 #define PSNR_LONGTEXT N_( "This has no effect on actual encoding quality, "\
     "it just prevents the stats from being calculated (for speed)." )
 
+#define QUIET_TEXT N_("Quiet mode")
+#define QUIET_LONGTEXT N_( "Quiet mode.")
+
 #define VERBOSE_TEXT N_("Statistics")
 #define VERBOSE_LONGTEXT N_( "Print stats for each frame.")
 
@@ -248,10 +269,17 @@
   { N_("default"), N_("none"), N_("fast"), N_("normal"),
     N_("slow"), N_("all") };
 
+#if X264_BUILD >= 45 /* r457 */
 static char *direct_pred_list[] =
+  { "", "none", "spatial", "temporal", "auto" };
+static char *direct_pred_list_text[] =
+  { N_("default"), N_("none"), N_("spatial"), N_("temporal"), N_("auto") };
+#else
+static char *direct_pred_list[] =
   { "", "none", "spatial", "temporal" };
 static char *direct_pred_list_text[] =
   { N_("default"), N_("none"), N_("spatial"), N_("temporal") };
+#endif
 
 vlc_module_begin();
     set_description( _("H.264/MPEG4 AVC encoder (using x264 library)"));
@@ -301,6 +329,9 @@
               NF_LONGTEXT, VLC_FALSE );
         add_deprecated( SOUT_CFG_PREFIX "loopfilter", VLC_FALSE ); /* Deprecated since 0.8.5 */
 
+    add_string( SOUT_CFG_PREFIX "filter", "", NULL, FILTER_TEXT,
+                 FILTER_LONGTEXT, VLC_FALSE );
+
 /* Ratecontrol */
 
     add_integer( SOUT_CFG_PREFIX "qp", 26, NULL, QP_TEXT, QP_LONGTEXT,
@@ -367,11 +398,12 @@
 
 /* Analysis */
 
-    add_string( SOUT_CFG_PREFIX "analyse", "all", NULL, ANALYSE_TEXT,
+    /* x264 analyse = none (default). set at least "normal" mode. */
+    add_string( SOUT_CFG_PREFIX "analyse", "normal", NULL, ANALYSE_TEXT,
                 ANALYSE_LONGTEXT, VLC_FALSE );
         change_string_list( enc_analyse_list, enc_analyse_list_text, 0 );
 
-    add_string( SOUT_CFG_PREFIX "direct", "temporal", NULL, DIRECT_PRED_TEXT,
+    add_string( SOUT_CFG_PREFIX "direct", "spatial", NULL, DIRECT_PRED_TEXT,
                 DIRECT_PRED_LONGTEXT, VLC_FALSE );
         change_string_list( direct_pred_list, direct_pred_list_text, 0 );
 
@@ -393,11 +425,7 @@
     add_integer( SOUT_CFG_PREFIX "subme", 5, NULL, SUBME_TEXT,
                  SUBME_LONGTEXT, VLC_FALSE );
         add_deprecated( SOUT_CFG_PREFIX "subpel", VLC_FALSE ); /* Deprecated since 0.8.5 */
-#if X264_BUILD >= 30 /* r262 */
-        change_integer_range( 1, 6 );
-#else
-        change_integer_range( 1, 5 );
-#endif
+        change_integer_range( 1, SUBME_MAX );
 
 #if X264_BUILD >= 41 /* r368 */
     add_bool( SOUT_CFG_PREFIX "b-rdo", 0, NULL, B_RDO_TEXT,
@@ -449,6 +477,9 @@
     add_bool( SOUT_CFG_PREFIX "psnr", 0, NULL, PSNR_TEXT,
               PSNR_LONGTEXT, VLC_FALSE );
 
+    add_bool( SOUT_CFG_PREFIX "quiet", 0, NULL, QUIET_TEXT,
+              QUIET_LONGTEXT, VLC_FALSE );
+
 #if X264_BUILD >= 0x000e /* r81 */
     add_bool( SOUT_CFG_PREFIX "verbose", 0, NULL, VERBOSE_TEXT,
               VERBOSE_LONGTEXT, VLC_FALSE );
@@ -462,12 +493,13 @@
 static const char *ppsz_sout_options[] = {
     "8x8dct", "analyse", "asm", "bframes", "bime", "bpyramid", "b-adapt",
     "b-bias", "b-rdo", "cabac", "chroma-me", "chroma-qp-offset", "cplxblur",
-    "crf", "direct", "fast-pskip", "frameref", "ipratio", "keyint",
-    "keyint-min", "loopfilter", "me", "merange", "min-keyint", "mixed-refs",
-    "nf", "nr", "pbratio", "psnr", "qblur", "qp", "qcomp", "qpstep",
-    "qpmax", "qpmin", "qp-max", "qp-min", "ratetol", "ref", "scenecut",
-    "subme", "subpel", "tolerance", "trellis", "verbose", "vbv-bufsize",
-    "vbv-init", "vbv-maxrate", "weightb" , NULL
+    "crf", "direct", "filter", "fast-pskip", "frameref", "ipratio",
+    "keyint", "keyint-min", "loopfilter", "me", "merange", "min-keyint",
+    "mixed-refs", "nf", "nr", "pbratio", "psnr", "qblur", "qp",
+    "qcomp", "qpstep", "qpmax", "qpmin", "qp-max", "qp-min", "quiet",
+    "ratetol", "ref", "scenecut", "subme", "subpel", "tolerance",
+    "trellis", "verbose", "vbv-bufsize", "vbv-init", "vbv-maxrate",
+    "weightb", NULL
 };
 
 static block_t *Encode( encoder_t *, picture_t * );
@@ -598,6 +630,15 @@
     var_Get( p_enc, SOUT_CFG_PREFIX "nf", &val );
     p_sys->param.b_deblocking_filter = !val.b_bool;
 
+    var_Get( p_enc, SOUT_CFG_PREFIX "filter", &val );
+    if( val.psz_string )
+    {
+        char *p = strchr( val.psz_string, ':' );
+        p_sys->param.i_deblocking_filter_alphac0 = atoi( val.psz_string );
+        p_sys->param.i_deblocking_filter_beta = p ? atoi( p+1 ) : p_sys->param.i_deblocking_filter_alphac0;
+        free( val.psz_string );
+    }
+
     var_Get( p_enc, SOUT_CFG_PREFIX "ipratio", &val );
     p_sys->param.rc.f_ip_factor = val.f_float;
 
@@ -618,6 +659,9 @@
     if( val.b_bool ) p_sys->param.i_log_level = X264_LOG_DEBUG;
 #endif
 
+    var_Get( p_enc, SOUT_CFG_PREFIX "quiet", &val );
+    if( val.b_bool ) p_sys->param.i_log_level = X264_LOG_NONE;
+
     var_Get( p_enc, SOUT_CFG_PREFIX "keyint", &val );
 #if X264_BUILD >= 0x000e
     if( val.i_int > 0 ) p_sys->param.i_keyint_max = val.i_int;
@@ -651,14 +695,9 @@
         p_sys->param.i_scenecut_threshold = val.i_int;
 #endif
 
-#if X264_BUILD >= 30
     var_Get( p_enc, SOUT_CFG_PREFIX "subme", &val );
-    if( val.i_int >= 1 && val.i_int <= 6 )
+    if( val.i_int >= 1 && val.i_int <= SUBME_MAX )
         p_sys->param.analyse.i_subpel_refine = val.i_int;
-#else
-    if( val.i_int >= 1 && val.i_int <= 5 )
-        p_sys->param.analyse.i_subpel_refine = val.i_int;
-#endif
 
 #if X264_BUILD >= 24
     var_Get( p_enc, SOUT_CFG_PREFIX "me", &val );
@@ -698,6 +737,12 @@
     {
         p_sys->param.analyse.i_direct_mv_pred = X264_DIRECT_PRED_TEMPORAL;
     }
+#if X264_BUILD >= 45 /* r457 */
+    else if( !strcmp( val.psz_string, "auto" ) )
+    {
+        p_sys->param.analyse.i_direct_mv_pred = X264_DIRECT_PRED_AUTO;
+    }
+#endif    
     if( val.psz_string ) free( val.psz_string );
 
     var_Get( p_enc, SOUT_CFG_PREFIX "psnr", &val );
@@ -831,22 +876,6 @@
         p_sys->param.i_fps_num = p_enc->fmt_in.video.i_frame_rate;
         p_sys->param.i_fps_den = p_enc->fmt_in.video.i_frame_rate_base;
     }
-    if( !(p_enc->p_libvlc->i_cpu & CPU_CAPABILITY_MMX) )
-    {
-        p_sys->param.cpu &= ~X264_CPU_MMX;
-    }
-    if( !(p_enc->p_libvlc->i_cpu & CPU_CAPABILITY_MMXEXT) )
-    {
-        p_sys->param.cpu &= ~X264_CPU_MMXEXT;
-    }
-    if( !(p_enc->p_libvlc->i_cpu & CPU_CAPABILITY_SSE) )
-    {
-        p_sys->param.cpu &= ~X264_CPU_SSE;
-    }
-    if( !(p_enc->p_libvlc->i_cpu & CPU_CAPABILITY_SSE2) )
-    {
-        p_sys->param.cpu &= ~X264_CPU_SSE2;
-    }
 
 #if X264_BUILD >= 29
     if( p_enc->i_threads >= 1 )
